#include "clean900.h"
#include "ui_clean900.h"

#include <QProcess>

CleaN900::CleaN900(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::CleaN900)
{
    ui->setupUi(this);
}

CleaN900::~CleaN900()
{
    delete ui;
}

void CleaN900::on_actionAbout_triggered()
{
    QProcess process;
    process.start("sh info.sh");
    process.waitForFinished();
}

void CleaN900::on_actionXTerm_triggered()
{
    QProcess process;
    process.start("sh term.sh");
    process.waitForFinished();
}

void CleaN900::on_commandLinkButton_clicked()
{
    QProcess process;
    process.start("sh browser.sh");
    process.waitForFinished();
}

void CleaN900::on_pushClean_clicked()
{
    QProcess process;
    process.start("sh clean-en.sh");
    process.waitForFinished();
}

void CleaN900::on_pushAutoclean_clicked()
{
    QProcess process;
    process.start("sh autoclean-en.sh");
    process.waitForFinished();
}

void CleaN900::on_pushAutoremove_clicked()
{
    QProcess process;
    process.start("sh autoremove-en.sh");
    process.waitForFinished();
}

void CleaN900::on_pushPurge_clicked()
{
    QProcess process;
    process.start("sh purge-en.sh");
    process.waitForFinished();
}

void CleaN900::on_pushUpdate_clicked()
{
    QProcess process;
    process.start("sh update-en.sh");
    process.waitForFinished();
}

void CleaN900::on_pushUpgrade_clicked()
{
    QProcess process;
    process.start("sh upgrade-en.sh");
    process.waitForFinished();
}

void CleaN900::on_pushReboot_clicked()
{
    QProcess process;
    process.start("sh reboot-en.sh");
    process.waitForFinished();
}

void CleaN900::on_pushBackup_clicked()
{
    QProcess process;
    process.start("sh backup-en.sh");
    process.waitForFinished();
}

void CleaN900::on_pushRip_clicked()
{
    QProcess process;
    process.start("sh ripbackup-en.sh");
    process.waitForFinished();
}

void CleaN900::on_pushInstall_clicked()
{
    QProcess process;
    process.start("sh install-en.sh");
    process.waitForFinished();
}

void CleaN900::on_pushRemove_clicked()
{
    QProcess process;
    process.start("sh remove-en.sh");
    process.waitForFinished();
}

void CleaN900::on_pushReboot_2_clicked()
{
    QProcess process;
    process.start("sh reboot-en.sh");
    process.waitForFinished();
}

void CleaN900::on_pushRoot_clicked()
{
    QProcess process;
    process.start("sh root.sh");
    process.waitForFinished();
}

void CleaN900::on_pushMydocs_clicked()
{
    QProcess process;
    process.start("sh mydocs.sh");
    process.waitForFinished();
}

void CleaN900::on_pushRam_clicked()
{
    QProcess process;
    process.start("sh ram.sh");
    process.waitForFinished();
}

void CleaN900::on_pushOpt_clicked()
{
    QProcess process;
    process.start("sh opt.sh");
    process.waitForFinished();
}

void CleaN900::on_pushBat_clicked()
{
    QProcess process;
    process.start("sh bat.sh");
    process.waitForFinished();
}

void CleaN900::on_pushApp_clicked()
{
    QProcess process;
    process.start("sh app.sh");
    process.waitForFinished();
}

void CleaN900::on_pushCard_clicked()
{
    QProcess process;
    process.start("sh card.sh");
    process.waitForFinished();
}

void CleaN900::on_pushUpTem_clicked()
{
    QProcess process;
    process.start("sh uptemp.sh");
    process.waitForFinished();
}

void CleaN900::on_pushPart_clicked()
{
    QProcess process;
    process.start("sh fsck.sh");
    process.waitForFinished();
}

void CleaN900::on_pushDet_clicked()
{
    QProcess process;
    process.start("sh signal.sh");
    process.waitForFinished();
}

void CleaN900::on_pushDpkgPurge_clicked()
{
    QProcess process;
    process.start("sh purgedpkg.sh");
    process.waitForFinished();
}

void CleaN900::on_actionHardware_Details_triggered()
{
    QProcess process;
    process.start("sh harddet.sh");
    process.waitForFinished();
}

void CleaN900::on_actionDonate_triggered()
{
    QProcess process;
    process.start("sh donate.sh");
    process.waitForFinished();
}

void CleaN900::on_searchhome_clicked()
{
    QProcess process;
    process.start("sh searchall.sh");
    process.waitForFinished();
}

void CleaN900::on_searchMy_clicked()
{
    QProcess process;
    process.start("sh searchMyDocs.sh");
    process.waitForFinished();
}

void CleaN900::on_search_clicked()
{
    QProcess process;
    process.start("sh searchspe.sh");
    process.waitForFinished();
}

void CleaN900::on_pushButton_clicked()
{
    QProcess process;
    process.start("sh dicell.sh");
    process.waitForFinished();
}

void CleaN900::on_difm_clicked()
{
    QProcess process;
    process.start("sh difm.sh");
    process.waitForFinished();
}

void CleaN900::on_diblue_clicked()
{
    QProcess process;
    process.start("sh diblue.sh");
    process.waitForFinished();
}

void CleaN900::on_encell_clicked()
{
    QProcess process;
    process.start("sh encell.sh");
    process.waitForFinished();
}

void CleaN900::on_enfm_clicked()
{
    QProcess process;
    process.start("sh enfm.sh");
    process.waitForFinished();
}

void CleaN900::on_enblue_clicked()
{
    QProcess process;
    process.start("sh enblue.sh");
    process.waitForFinished();
}

void CleaN900::on_general_clicked()
{
    QProcess process;
    process.start("sh engen.sh");
    process.waitForFinished();
}

void CleaN900::on_silent_clicked()
{
    QProcess process;
    process.start("sh ensile.sh");
    process.waitForFinished();
}
